package main

import (
	"flag"
	"sdk_api/config"
	"sdk_api/dao"
	"sdk_api/gassender"
	"sdk_api/server"
	"sdk_api/service"

	log "github.com/sirupsen/logrus"
)

func init() {
	log.SetFormatter(&log.TextFormatter{
		FullTimestamp: true,
	})
}

func main() {
	flag.Parse()
	cfg, err := config.New()
	if err != nil {
		panic(err)
	}

	gs := runGasSender(cfg)

	da, err := dao.New(cfg)
	if err != nil {
		panic(err)
	}

	if cfg.Debug {
		log.SetLevel(log.DebugLevel)
	}

	svs := service.New(cfg, da, gs)

	server.StartServer(svs, cfg)
}

func runGasSender(cfg *config.Config) *gassender.GasSender {
	gs, err := gassender.NewGasSender(cfg.GasSender.RPC, cfg.GasSender.PrivateKey, cfg.GasSender.UserContract)
	if err != nil {
		panic(err)
	}
	gs.Run()
	// gs.AonLogin(common.HexToAddress("aaaa"), "1", "1")
	return gs
}
