package config

import (
	"flag"

	"github.com/BurntSushi/toml"
)

type Config struct {
	Debug     bool            `toml:"debug"`
	MySQL     MysqlConfig     `toml:"mysql"`
	Server    ServerConfig    `toml:"server"`
	GasSender GasSenderConfig `toml:"gas_sender"`
	TGBot     TGBotConfig     `toml:"tg_bot"`
}

type MysqlConfig struct {
	Host        string `toml:"host"`
	Port        int    `toml:"port"`
	User        string `toml:"user"`
	Password    string `toml:"password"`
	Database    string `toml:"database"`
	MaxConn     int    `toml:"max_conn"`
	MaxIdleConn int    `toml:"max_idle_conn"`
}

type ServerConfig struct {
	Listen string `toml:"listen"`
}

type GasSenderConfig struct {
	PrivateKey   string `toml:"private_key"`
	UserContract string `toml:"user_contract"`
	RPC          string `toml:"rpc"`
}

type TGBotConfig struct {
	Tokens []string `toml:"tokens"`
}

var confPath = flag.String("c", "config.toml", "config file path")

func New() (config *Config, err error) {
	config = new(Config)
	_, err = toml.DecodeFile(*confPath, config)
	return
}
